[GRASS-SVN] r56915 - grass/branches/releasebranch_6_4/gui/wxpython/scripts

svn_grass at osgeo.org svn_grass at osgeo.org
Mon Jun 24 18:31:32 PDT 2013


Author: hamish
Date: 2013-06-24 18:31:32 -0700 (Mon, 24 Jun 2013)
New Revision: 56915

Modified:
   grass/branches/releasebranch_6_4/gui/wxpython/scripts/vkrige.py
Log:
update to modern python module names (merge from devbr6)

Modified: grass/branches/releasebranch_6_4/gui/wxpython/scripts/vkrige.py
===================================================================
--- grass/branches/releasebranch_6_4/gui/wxpython/scripts/vkrige.py	2013-06-25 01:27:12 UTC (rev 56914)
+++ grass/branches/releasebranch_6_4/gui/wxpython/scripts/vkrige.py	2013-06-25 01:31:32 UTC (rev 56915)
@@ -33,14 +33,14 @@
     sys.exit(_("No GRASS-python library found."))
 ### wxGUI imports
 
-GUIModulesPath = os.path.join(os.getenv("GISBASE"), "etc", "wxpython", "gui_modules")
+GUIModulesPath = os.path.join(os.getenv("GISBASE"), "etc", "wxpython", "gui_core")
 sys.path.append(GUIModulesPath)
 
 import globalvar
 import gselect
 import goutput
-import menuform
-from preferences import globalSettings as UserSettings
+import forms
+from settings import UserSettings
 #import help
 
 import wx
@@ -101,7 +101,7 @@
         for Rpackage in ["gstat"]: # , "geoR"]: #@TODO: enable it if/when it'll be implemented.
             self.CreatePage(package = Rpackage, Rinstance = Rinstance, controller = controller)
         
         ## Command output. From menuform module, cmdPanel class
         self.goutput = goutput.GMConsole(parent = self, margin = False,
                                          notebook = self.RPackagesBook)
         self.goutputId = self.RPackagesBook.GetPageCount()
@@ -101,7 +101,7 @@
             self.CreatePage(package = Rpackage, Rinstance = Rinstance, controller = controller)
         
-        ## Command output. From menuform module, cmdPanel class
+        ## Command output. From forms.py module, cmdPanel class
         self.goutput = goutput.GMConsole(parent = self, margin = False,
                                          notebook = self.RPackagesBook)



More information about the grass-commit mailing list